%bcond_with bootstrap
%global upstream_name commons-lang3

Summary:        Provides a host of helper utilities for the java.lang API
Name:           apache-%{upstream_name}
Version:        3.17.0
Release:        1%{?dist}
License:        ASL 2.0
URL:            https://commons.apache.org/lang
Source0:        https://archive.apache.org/dist/commons/lang/source/commons-lang3-%{version}-src.tar.gz

Patch3000:      0001-Remove-test-dependency-on-JUnit-Pioneer.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap-openjdk8
%else
BuildRequires:  maven-local maven >= 3.9.9
BuildRequires:  maven-buildrequires >= 3.9.9
# for using maven macro
BuildRequires:  javapackages-common
%endif

BuildArch:      noarch
Obsoletes:      %{name}-javadoc < %{version}-%{release}

%description
The standard Java libraries fail to provide enough methods for
manipulation of its core classes. The Commons Lang Component provides
these extra methods.
The Commons Lang Component provides a host of helper utilities for the
java.lang API, notably String manipulation methods, basic numerical
methods, object reflection, creation and serialization, and System
properties. Additionally it contains an inheritable enum type, an
exception structure that supports multiple types of nested-Exceptions
and a series of utilities dedicated to help with building methods, such
as hashCode, toString and equals.
With version of commons-lang 3.x, developers decided to change API and
therefore created differently named artifact and jar files. This is
the new version, while apache-commons-lang is the compatibility
package.

%prep
%autosetup -p1 -n %{upstream_name}-%{version}-src

%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_dep org.openjdk.jmh:jmh-core
%pom_remove_dep org.openjdk.jmh:jmh-generator-annprocess
%pom_remove_dep org.apache.commons:commons-text
 
%mvn_file : %{name} %{upstream_name}
rm -rf .xmvn

sed -i 's/\s*public void testParseSync().*/@org.junit.jupiter.api.Disabled\n&/' \
    src/test/java/org/apache/commons/lang3/time/FastDateFormatTest.java
rm src/test/java/org/apache/commons/lang3/RandomStringUtilsTest.java
rm src/test/java/org/apache/commons/lang3/HashSetvBitSetTest.java
sed -i '/<argLine>/d' pom.xml

%build
/usr/bin/mvn -X -o clean package -Dgpg.skip=true -Dmaven.test.skip=true -Dmaven.javadoc.skip=true -Dmaven.repo.local=/usr/lib/maven/repository/ -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
mkdir -p /usr/share/maven-poms
install -pm 0644 -D target/%{upstream_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
ln -sf %{name}.jar %{buildroot}%{_javadir}/%{upstream_name}.jar
install -pm 0644 -D pom.xml %{buildroot}%{_datadir}/maven-poms/%{name}.pom
ln -sf %{name}.pom %{buildroot}%{_datadir}/maven-poms/%{upstream_name}.pom

%files
%license LICENSE.txt NOTICE.txt
%doc RELEASE-NOTES.txt
%{_javadir}/%{name}.jar
%{_javadir}/%{upstream_name}.jar
%{_datadir}/maven-poms/%{name}.pom
%{_datadir}/maven-poms/%{upstream_name}.pom


%changelog
* Tue Jan 21 2025 Xiaojie Chen <jackxjchen@tencent.com> - 3.17.0-1
- [Type] other
- [DESC] Upgrade to upstream version 3.17.0
- Remove the dependency on xmvn

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.12.0-9
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.12.0-8
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.12.0-7
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.12.0-6
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 20 2023 Xiaojie Chen <jackxjchen@tencent.com> - 3.12.0-5
- Disable bootstrap

* Wed Apr 12 2023 Xiaojie Chen <jackxjchen@tencent.com> - 3.12.0-4
- Using maven-local-openjdk8 as default

* Wed Apr 12 2023 Xiaojie Chen <jackxjchen@tencent.com> - 3.12.0-3
- Rewritten spec for maven 3.8.6

* Fri Mar 24 2023 rockerzhu <rockerzhu@tencent.com> - 3.12.0-2
- Rebuild

* Tue Dec 20 2022 Zhao Zhen <jeremiazhao@tencent.com> - 3.12.0-1
- initial
